@@ -90,14 +90,6 @@ def setup_deploy_key(keypath='github_deploy_key', key_ext='.enc'):
     run(['ssh-add', os.path.expanduser('~/.ssh/' + key_filename)])
 
 def run_command_hiding_token(args, token, shell=False):
-    if not shell:
-        command = ' '.join(map(shlex.quote, args))
-    else:
-        command = args
-    command = command.replace(token.decode('utf-8'), '~'*len(token))
-    print(blue(command))
-    sys.stdout.flush()
-
     if token:
         stdout = stderr = subprocess.PIPE
     else:
@@ -143,9 +135,19 @@ def run(args, shell=False, exit=True):
         token = b''
     else:
         token = get_token()
+
+    if not shell:
+        command = ' '.join(map(shlex.quote, args))
+    else:
+        command = args
+    command = command.replace(token.decode('utf-8'), '~'*len(token))
+    print(blue(command))
+    sys.stdout.flush()
+
     returncode = run_command_hiding_token(args, token, shell=shell)
+
     if exit and returncode != 0:
-        sys.exit(returncode)
+        sys.exit(red("%s failed: %s" % (command, returncode)))
     return returncode
 
 def get_current_repo():
@@ -455,8 +457,7 @@ The doctr command that was run is
     )
 
     # Only commit if there were changes
-    if subprocess.run(['git', 'diff-index', '--quiet', 'HEAD', '--'],
-        stdout=subprocess.PIPE, stderr=subprocess.PIPE).returncode != 0:
+    if run(['git', 'diff-index', '--exit-code', '--cached', '--quiet', 'HEAD', '--'], exit=False) != 0:
         print("Committing")
         run(['git', 'commit', '-am', commit_message])
         return True
@@ -476,9 +477,11 @@ def push_docs(deploy_branch='gh-pages', retries=3):
     code = 1
     while code and retries:
         print("Pulling")
-        code = run(['git', 'pull', '-s', 'recursive', '-X', 'ours', 'doctr_remote', deploy_branch])
+        code = run(['git', 'pull', '-s', 'recursive', '-X', 'ours',
+            'doctr_remote', deploy_branch], exit=False)
         print("Pushing commit")
-        code = run(['git', 'push', '-q', 'doctr_remote', '{}:{}'.format(DOCTR_WORKING_BRANCH, deploy_branch)])
+        code = run(['git', 'push', '-q', 'doctr_remote',
+            '{}:{}'.format(DOCTR_WORKING_BRANCH, deploy_branch)], exit=False)
         if code:
             retries -= 1
             print("Push failed, retrying")
